==> jc-1.4.0.tar.gz: polyglot/parse/VarDeclarator.c <==
// public class polyglot.parse.VarDeclarator

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class a33c697a7834ba70 polyglot_ast_Expr
// @dep_class e329cd839509c30c polyglot_parse_VarDeclarator
// @dep_class 32c9a088c5dac046 polyglot_util_Position

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header polyglot_ast_Expr
// @dep_header polyglot_parse_VarDeclarator
// @dep_header polyglot_util_Position

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "polyglot/ast/Expr.h"
#include "polyglot/parse/VarDeclarator.h"
#include "polyglot/util/Position.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// public polyglot.util.Position pos
static _jc_field _jc_polyglot_parse_VarDeclarator$field_info$pos = {
	.name=		"pos",
	.signature=	"Lpolyglot/util/Position;",
	.class=		&_jc_polyglot_parse_VarDeclarator$type,
	.type=		&_jc_polyglot_util_Position$type,
	.access_flags=	_JC_ACC_PUBLIC,
	.offset=	_JC_OFFSETOF(_jc_polyglot_parse_VarDeclarator$object, refs[-1].polyglot_parse_VarDeclarator.pos),
};

// public java.lang.String name
static _jc_field _jc_polyglot_parse_VarDeclarator$field_info$name = {
	.name=		"name",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_polyglot_parse_VarDeclarator$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PUBLIC,
	.offset=	_JC_OFFSETOF(_jc_polyglot_parse_VarDeclarator$object, refs[-1].polyglot_parse_VarDeclarator.name),
};

// public int dims
static _jc_field _jc_polyglot_parse_VarDeclarator$field_info$dims = {
	.name=		"dims",
	.signature=	"I",
	.class=		&_jc_polyglot_parse_VarDeclarator$type,
	.type=		&_jc_int$prim$type,
	.access_flags=	_JC_ACC_PUBLIC,
	.offset=	_JC_OFFSETOF(_jc_polyglot_parse_VarDeclarator$object, nonrefs.polyglot_parse_VarDeclarator.dims),
};

// public polyglot.ast.Expr init
static _jc_field _jc_polyglot_parse_VarDeclarator$field_info$init = {
	.name=		"init",
	.signature=	"Lpolyglot/ast/Expr;",
	.class=		&_jc_polyglot_parse_VarDeclarator$type,
	.type=		&_jc_polyglot_ast_Expr$type,
	.access_flags=	_JC_ACC_PUBLIC,
	.offset=	_JC_OFFSETOF(_jc_polyglot_parse_VarDeclarator$object, refs[-1].polyglot_parse_VarDeclarator.init),
};

// Fields
static _jc_field *const _jc_polyglot_parse_VarDeclarator$fields[] = {
	&_jc_polyglot_parse_VarDeclarator$field_info$init,
	&_jc_polyglot_parse_VarDeclarator$field_info$name,
	&_jc_polyglot_parse_VarDeclarator$field_info$pos,
	&_jc_polyglot_parse_VarDeclarator$field_info$dims
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(polyglot.util.Position, java.lang.String)
//

static _jc_linenum _jc_polyglot_parse_VarDeclarator$linenum_table$_init$e1025501fac123ee[];

static const unsigned char _jc_polyglot_parse_VarDeclarator$param_ptypes$_init$e1025501fac123ee[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_polyglot_parse_VarDeclarator$param_types$_init$e1025501fac123ee[] = {
	&_jc_polyglot_util_Position$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_polyglot_parse_VarDeclarator$method_info$_init$e1025501fac123ee = {
	.name=			"<init>",
	.signature=		"(Lpolyglot/util/Position;Ljava/lang/String;)V",
	.class=			&_jc_polyglot_parse_VarDeclarator$type,
	.param_types=		&_jc_polyglot_parse_VarDeclarator$param_types$_init$e1025501fac123ee,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_parse_VarDeclarator$param_ptypes$_init$e1025501fac123ee,
	.signature_hash=	_JC_JLONG(0xe1025501fac123ee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_parse_VarDeclarator$method$_init$e1025501fac123ee,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	5,
	      .table=	_jc_polyglot_parse_VarDeclarator$linenum_table$_init$e1025501fac123ee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_parse_VarDeclarator, _init$e1025501fac123ee);

void
_jc_polyglot_parse_VarDeclarator$method$_init$e1025501fac123ee(_jc_env *const env, _jc_polyglot_parse_VarDeclarator$object *this, _jc_polyglot_util_Position$object *param0, _jc_java_lang_String$object *param1)
{
	struct _jc_polyglot_parse_VarDeclarator$object *r0;
	struct _jc_polyglot_util_Position$object *r1;
	struct _jc_java_lang_String$object *r2;

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(16);				// 0
	_JC_REF_FIELD(env, r0, polyglot_parse_VarDeclarator, pos) = r1;
	_JC_LINE_NUMBER(17);				// 1
	_JC_REF_FIELD(env, r0, polyglot_parse_VarDeclarator, name) = r2;
	_JC_LINE_NUMBER(18);				// 2
	_JC_PRIM_FIELD(env, r0, polyglot_parse_VarDeclarator, dims) = 0;
	_JC_LINE_NUMBER(19);				// 3
	_JC_REF_FIELD(env, r0, polyglot_parse_VarDeclarator, init) = _JC_NULL;
	_JC_LINE_NUMBER(20);				// 4
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public polyglot.util.Position position()
//

static _jc_linenum _jc_polyglot_parse_VarDeclarator$linenum_table$position$bb89333b1e4c840c[];

static const unsigned char _jc_polyglot_parse_VarDeclarator$param_ptypes$position$bb89333b1e4c840c[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_polyglot_parse_VarDeclarator$method_info$position$bb89333b1e4c840c = {
	.name=			"position",
	.signature=		"()Lpolyglot/util/Position;",
	.class=			&_jc_polyglot_parse_VarDeclarator$type,
	.return_type=		&_jc_polyglot_util_Position$type,
	.param_ptypes=		&_jc_polyglot_parse_VarDeclarator$param_ptypes$position$bb89333b1e4c840c,
	.signature_hash=	_JC_JLONG(0xbb89333b1e4c840c),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_parse_VarDeclarator$method$position$bb89333b1e4c840c,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_parse_VarDeclarator$vtable, polyglot_parse_VarDeclarator.position$bb89333b1e4c840c) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_parse_VarDeclarator$linenum_table$position$bb89333b1e4c840c
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_parse_VarDeclarator, position$bb89333b1e4c840c);

_jc_polyglot_util_Position$object *
_jc_polyglot_parse_VarDeclarator$method$position$bb89333b1e4c840c(_jc_env *const env, _jc_polyglot_parse_VarDeclarator$object *this)
{
	struct _jc_polyglot_parse_VarDeclarator$object *r0;
	struct _jc_polyglot_util_Position$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(23);				// 0
	r1 = _JC_REF_FIELD(env, r0, polyglot_parse_VarDeclarator, pos);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_polyglot_parse_VarDeclarator$methods[] = {
	&_jc_polyglot_parse_VarDeclarator$method_info$_init$e1025501fac123ee,
	&_jc_polyglot_parse_VarDeclarator$method_info$position$bb89333b1e4c840c
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_polyglot_parse_VarDeclarator$instanceof_hash_bucket_12[] = {
	&_jc_polyglot_parse_VarDeclarator$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_parse_VarDeclarator$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_polyglot_parse_VarDeclarator$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[12]=	_jc_polyglot_parse_VarDeclarator$instanceof_hash_bucket_12,
	[113]=	_jc_polyglot_parse_VarDeclarator$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_polyglot_parse_VarDeclarator$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "polyglot/ast/Expr",	_JC_JLONG(0xa33c697a7834ba70) },
	{ "polyglot/util/Position",	_JC_JLONG(0x32c9a088c5dac046) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_polyglot_parse_VarDeclarator$vtype _jc_polyglot_parse_VarDeclarator$type = {
    .type= {
	.name=			"polyglot/parse/VarDeclarator",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xe329cd839509c30c),
		.source_file=		"VarDeclarator.java",
		.instance_size=		sizeof(_jc_polyglot_parse_VarDeclarator$refs) + sizeof(_jc_polyglot_parse_VarDeclarator$object),
		.num_virtual_refs=	3,
		.num_fields=		sizeof(_jc_polyglot_parse_VarDeclarator$fields) / sizeof(*_jc_polyglot_parse_VarDeclarator$fields),
		.fields=		_jc_polyglot_parse_VarDeclarator$fields,
		.num_methods=		sizeof(_jc_polyglot_parse_VarDeclarator$methods) / sizeof(*_jc_polyglot_parse_VarDeclarator$methods),
		.methods=		_jc_polyglot_parse_VarDeclarator$methods,
		.instanceof_hash_table=	_jc_polyglot_parse_VarDeclarator$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_polyglot_parse_VarDeclarator$class_depends) / sizeof(*_jc_polyglot_parse_VarDeclarator$class_depends),
		.class_depends=		_jc_polyglot_parse_VarDeclarator$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.polyglot_parse_VarDeclarator= {
	    .position$bb89333b1e4c840c=
		&_jc_polyglot_parse_VarDeclarator$method$position$bb89333b1e4c840c,
	},
    }
};

==> jc-1.4.5.tar.gz: polyglot/parse/VarDeclarator.c <==
// public class polyglot.parse.VarDeclarator

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class a33c697a7834ba70 polyglot_ast_Expr
// @dep_class e329cd839509c30c polyglot_parse_VarDeclarator
// @dep_class 32c9a088c5dac046 polyglot_util_Position

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header polyglot_ast_Expr
// @dep_header polyglot_parse_VarDeclarator
// @dep_header polyglot_util_Position

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "polyglot/ast/Expr.h"
#include "polyglot/parse/VarDeclarator.h"
#include "polyglot/util/Position.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// public polyglot.util.Position pos
static _jc_field _jc_polyglot_parse_VarDeclarator$field_info$pos = {
	.name=		"pos",
	.signature=	"Lpolyglot/util/Position;",
	.class=		&_jc_polyglot_parse_VarDeclarator$type,
	.type=		&_jc_polyglot_util_Position$type,
	.access_flags=	_JC_ACC_PUBLIC,
	.offset=	_JC_OFFSETOF(_jc_polyglot_parse_VarDeclarator$object, refs[-1].polyglot_parse_VarDeclarator.pos),
};

// public java.lang.String name
static _jc_field _jc_polyglot_parse_VarDeclarator$field_info$name = {
	.name=		"name",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_polyglot_parse_VarDeclarator$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PUBLIC,
	.offset=	_JC_OFFSETOF(_jc_polyglot_parse_VarDeclarator$object, refs[-1].polyglot_parse_VarDeclarator.name),
};

// public int dims
static _jc_field _jc_polyglot_parse_VarDeclarator$field_info$dims = {
	.name=		"dims",
	.signature=	"I",
	.class=		&_jc_polyglot_parse_VarDeclarator$type,
	.type=		&_jc_int$prim$type,
	.access_flags=	_JC_ACC_PUBLIC,
	.offset=	_JC_OFFSETOF(_jc_polyglot_parse_VarDeclarator$object, nonrefs.polyglot_parse_VarDeclarator.dims),
};

// public polyglot.ast.Expr init
static _jc_field _jc_polyglot_parse_VarDeclarator$field_info$init = {
	.name=		"init",
	.signature=	"Lpolyglot/ast/Expr;",
	.class=		&_jc_polyglot_parse_VarDeclarator$type,
	.type=		&_jc_polyglot_ast_Expr$type,
	.access_flags=	_JC_ACC_PUBLIC,
	.offset=	_JC_OFFSETOF(_jc_polyglot_parse_VarDeclarator$object, refs[-1].polyglot_parse_VarDeclarator.init),
};

// Fields
static _jc_field *const _jc_polyglot_parse_VarDeclarator$fields[] = {
	&_jc_polyglot_parse_VarDeclarator$field_info$init,
	&_jc_polyglot_parse_VarDeclarator$field_info$name,
	&_jc_polyglot_parse_VarDeclarator$field_info$pos,
	&_jc_polyglot_parse_VarDeclarator$field_info$dims
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(polyglot.util.Position, java.lang.String)
//

static _jc_linenum _jc_polyglot_parse_VarDeclarator$linenum_table$_init$e1025501fac123ee[];

static const unsigned char _jc_polyglot_parse_VarDeclarator$param_ptypes$_init$e1025501fac123ee[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_polyglot_parse_VarDeclarator$param_types$_init$e1025501fac123ee[] = {
	&_jc_polyglot_util_Position$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_polyglot_parse_VarDeclarator$method_info$_init$e1025501fac123ee = {
	.name=			"<init>",
	.signature=		"(Lpolyglot/util/Position;Ljava/lang/String;)V",
	.class=			&_jc_polyglot_parse_VarDeclarator$type,
	.param_types=		&_jc_polyglot_parse_VarDeclarator$param_types$_init$e1025501fac123ee,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_parse_VarDeclarator$param_ptypes$_init$e1025501fac123ee,
	.signature_hash=	_JC_JLONG(0xe1025501fac123ee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_parse_VarDeclarator$method$_init$e1025501fac123ee,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	5,
	      .table=	_jc_polyglot_parse_VarDeclarator$linenum_table$_init$e1025501fac123ee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_parse_VarDeclarator, _init$e1025501fac123ee);

void _JC_JCNI_ATTR
_jc_polyglot_parse_VarDeclarator$method$_init$e1025501fac123ee(_jc_env *const env, _jc_polyglot_parse_VarDeclarator$object *this, _jc_polyglot_util_Position$object *param0, _jc_java_lang_String$object *param1)
{
	struct _jc_polyglot_parse_VarDeclarator$object *r0;
	struct _jc_polyglot_util_Position$object *r1;
	struct _jc_java_lang_String$object *r2;

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(16);				// 0
	_JC_REF_FIELD(env, r0, polyglot_parse_VarDeclarator, pos) = r1;
	_JC_LINE_NUMBER(17);				// 1
	_JC_REF_FIELD(env, r0, polyglot_parse_VarDeclarator, name) = r2;
	_JC_LINE_NUMBER(18);				// 2
	_JC_PRIM_FIELD(env, r0, polyglot_parse_VarDeclarator, dims) = 0;
	_JC_LINE_NUMBER(19);				// 3
	_JC_REF_FIELD(env, r0, polyglot_parse_VarDeclarator, init) = _JC_NULL;
	_JC_LINE_NUMBER(20);				// 4
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public polyglot.util.Position position()
//

static _jc_linenum _jc_polyglot_parse_VarDeclarator$linenum_table$position$bb89333b1e4c840c[];

static const unsigned char _jc_polyglot_parse_VarDeclarator$param_ptypes$position$bb89333b1e4c840c[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_polyglot_parse_VarDeclarator$method_info$position$bb89333b1e4c840c = {
	.name=			"position",
	.signature=		"()Lpolyglot/util/Position;",
	.class=			&_jc_polyglot_parse_VarDeclarator$type,
	.return_type=		&_jc_polyglot_util_Position$type,
	.param_ptypes=		&_jc_polyglot_parse_VarDeclarator$param_ptypes$position$bb89333b1e4c840c,
	.signature_hash=	_JC_JLONG(0xbb89333b1e4c840c),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_parse_VarDeclarator$method$position$bb89333b1e4c840c,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_parse_VarDeclarator$vtable, polyglot_parse_VarDeclarator.position$bb89333b1e4c840c) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_parse_VarDeclarator$linenum_table$position$bb89333b1e4c840c
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_parse_VarDeclarator, position$bb89333b1e4c840c);

_jc_polyglot_util_Position$object * _JC_JCNI_ATTR
_jc_polyglot_parse_VarDeclarator$method$position$bb89333b1e4c840c(_jc_env *const env, _jc_polyglot_parse_VarDeclarator$object *this)
{
	struct _jc_polyglot_parse_VarDeclarator$object *r0;
	struct _jc_polyglot_util_Position$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(23);				// 0
	r1 = _JC_REF_FIELD(env, r0, polyglot_parse_VarDeclarator, pos);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_polyglot_parse_VarDeclarator$methods[] = {
	&_jc_polyglot_parse_VarDeclarator$method_info$_init$e1025501fac123ee,
	&_jc_polyglot_parse_VarDeclarator$method_info$position$bb89333b1e4c840c
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_polyglot_parse_VarDeclarator$instanceof_hash_bucket_12[] = {
	&_jc_polyglot_parse_VarDeclarator$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_parse_VarDeclarator$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_polyglot_parse_VarDeclarator$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[12]=	_jc_polyglot_parse_VarDeclarator$instanceof_hash_bucket_12,
	[101]=	_jc_polyglot_parse_VarDeclarator$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_polyglot_parse_VarDeclarator$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "polyglot/ast/Expr",	_JC_JLONG(0xa33c697a7834ba70) },
	{ "polyglot/util/Position",	_JC_JLONG(0x32c9a088c5dac046) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_polyglot_parse_VarDeclarator$vtype _jc_polyglot_parse_VarDeclarator$type = {
    .type= {
	.name=			"polyglot/parse/VarDeclarator",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xe329cd839509c30c),
		.source_file=		"VarDeclarator.java",
		.instance_size=		sizeof(_jc_polyglot_parse_VarDeclarator$refs) + sizeof(_jc_polyglot_parse_VarDeclarator$object),
		.num_virtual_refs=	3,
		.num_fields=		sizeof(_jc_polyglot_parse_VarDeclarator$fields) / sizeof(*_jc_polyglot_parse_VarDeclarator$fields),
		.fields=		_jc_polyglot_parse_VarDeclarator$fields,
		.num_methods=		sizeof(_jc_polyglot_parse_VarDeclarator$methods) / sizeof(*_jc_polyglot_parse_VarDeclarator$methods),
		.methods=		_jc_polyglot_parse_VarDeclarator$methods,
		.instanceof_hash_table=	_jc_polyglot_parse_VarDeclarator$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_polyglot_parse_VarDeclarator$class_depends) / sizeof(*_jc_polyglot_parse_VarDeclarator$class_depends),
		.class_depends=		_jc_polyglot_parse_VarDeclarator$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.polyglot_parse_VarDeclarator= {
	    .position$bb89333b1e4c840c=
		&_jc_polyglot_parse_VarDeclarator$method$position$bb89333b1e4c840c,
	},
    }
};
